@@ -1,7 +1,7 @@
 from django.apps import AppConfig
 from django.core import checks
 
-from .checks import check_deprecated_settings
+from .checks import check_deprecated_settings, check_insecure_settings
 
 
 class AnymailBaseConfig(AppConfig):
@@ -10,3 +10,4 @@ class AnymailBaseConfig(AppConfig):
 
     def ready(self):
         checks.register(check_deprecated_settings)
+        checks.register(check_insecure_settings)
