@@ -5,9 +5,9 @@ from email.utils import quote as rfc822_quote
 from requests.structures import CaseInsensitiveDict
 
 from .base_requests import AnymailRequestsBackend, RequestsPayload
-from ..exceptions import AnymailConfigurationError, AnymailRequestsAPIError, AnymailWarning
+from ..exceptions import AnymailConfigurationError, AnymailWarning
 from ..message import AnymailRecipientStatus
-from ..utils import BASIC_NUMERIC_TYPES, Mapping, get_anymail_setting, timestamp, update_deep
+from ..utils import BASIC_NUMERIC_TYPES, Mapping, get_anymail_setting, update_deep
 
 
 class EmailBackend(AnymailRequestsBackend):
@@ -47,16 +47,11 @@ class EmailBackend(AnymailRequestsBackend):
                                       default="https://api.sendgrid.com/v3/")
         if not api_url.endswith("/"):
             api_url += "/"
-        super(EmailBackend, self).__init__(api_url, **kwargs)
+        super().__init__(api_url, **kwargs)
 
     def build_message_payload(self, message, defaults):
         return SendGridPayload(message, defaults, self)
 
-    def raise_for_status(self, response, payload, message):
-        if response.status_code < 200 or response.status_code >= 300:
-            raise AnymailRequestsAPIError(email_message=message, payload=payload, response=response,
-                                          backend=self)
-
     def parse_recipient_status(self, response, payload, message):
         # If we get here, the send call was successful.
         # (SendGrid uses a non-2xx response for any failures, caught in raise_for_status.)
@@ -84,9 +79,7 @@ class SendGridPayload(RequestsPayload):
         http_headers['Authorization'] = 'Bearer %s' % backend.api_key
         http_headers['Content-Type'] = 'application/json'
         http_headers['Accept'] = 'application/json'
-        super(SendGridPayload, self).__init__(message, defaults, backend,
-                                              headers=http_headers,
-                                              *args, **kwargs)
+        super().__init__(message, defaults, backend, headers=http_headers, *args, **kwargs)
 
     def get_api_endpoint(self):
         return "mail/send"
@@ -294,7 +287,7 @@ class SendGridPayload(RequestsPayload):
     def set_send_at(self, send_at):
         # Backend has converted pretty much everything to
         # a datetime by here; SendGrid expects unix timestamp
-        self.data["send_at"] = int(timestamp(send_at))  # strip microseconds
+        self.data["send_at"] = int(send_at.timestamp())  # strip microseconds
 
     def set_tags(self, tags):
         self.data["categories"] = tags
